@@ -1,8 +1,6 @@
 
 scaleBar = function(crs, pos="bottomright",scale.cex=1,outer=TRUE,...) {
 
-	require(rgdal, quietly=TRUE )
-
 	if(is.character(crs))
 		crs = CRS(crs)
 	if(class(crs) != "CRS")
@@ -17,8 +15,7 @@ scaleBar = function(crs, pos="bottomright",scale.cex=1,outer=TRUE,...) {
 		par(cex=forLegend$cex)
 	} 
 	forLegend$cex=1
-	
-	
+
 	xpoints = t(bbox(extent(par("usr"))))
 	
 	dashTemplate = " 2000 km "
@@ -30,9 +27,13 @@ scaleBar = function(crs, pos="bottomright",scale.cex=1,outer=TRUE,...) {
 	
 	xpoints = SpatialPoints(xpoints, proj4string=crs)
 
-
-	
-	xll = spTransform(xpoints, CRSobj=crsLL)
+	if(requireNamespace('rgdal', quietly=TRUE)) {	
+		xll = spTransform(xpoints, crsLL)
+	} else {
+		xll= xpoints
+		if(!length(grep("longlat", projection(xpoints))))
+			warning('rgdal not intalled, assuming the plot is long-lat')
+	}
 	
 
 	up = matrix(coordinates(xll)["centre",]+c(0,0.1),ncol=2,
@@ -43,8 +44,12 @@ scaleBar = function(crs, pos="bottomright",scale.cex=1,outer=TRUE,...) {
 					proj4string=CRS(proj4string(xll))))
 	
 	
-	xpoints2 = spTransform(xll[c("up","centre")], 
+	if(requireNamespace('rgdal', quietly=TRUE)) {	
+		xpoints2 = spTransform(xll[c("up","centre")], 
 			CRSobj=CRS(proj4string(xpoints)))
+} else{
+	xpoints2 = xll[c("up","centre")]			
+}
 	thediff=apply(coordinates(xpoints2), 2,diff)
 	north=atan(thediff[1]/thediff[2])
 	
